about summary refs log tree commit diff
path: root/src/libcollections
diff options
context:
space:
mode:
authorChris Wong <lambda.fairy@gmail.com>2015-02-14 12:56:32 +1300
committerChris Wong <lambda.fairy@gmail.com>2015-02-14 12:56:32 +1300
commitbc9084b9b7f21140ffbc051ecb2a0cd08e88f3bb (patch)
tree7eca299eb3e3c7f1494f067bc6dcb4c119c279dd /src/libcollections
parentcf636c233dfeef5abf0de8fb35e23c0a161810d2 (diff)
downloadrust-bc9084b9b7f21140ffbc051ecb2a0cd08e88f3bb.tar.gz
rust-bc9084b9b7f21140ffbc051ecb2a0cd08e88f3bb.zip
Rename `fmt::Writer` to `fmt::Write`
This brings it in line with its namesake in `std::io`.

[breaking-change]
Diffstat (limited to 'src/libcollections')
-rw-r--r--src/libcollections/fmt.rs4
-rw-r--r--src/libcollections/string.rs4
2 files changed, 4 insertions, 4 deletions
diff --git a/src/libcollections/string.rs b/src/libcollections/string.rs
index 63483d30dd2..69fd28d1723 100644
--- a/src/libcollections/string.rs
+++ b/src/libcollections/string.rs
@@ -950,7 +950,7 @@ pub trait ToString {
 impl<T: fmt::Display + ?Sized> ToString for T {
     #[inline]
     fn to_string(&self) -> String {
-        use core::fmt::Writer;
+        use core::fmt::Write;
         let mut buf = String::new();
         let _ = buf.write_fmt(format_args!("{}", self));
         buf.shrink_to_fit();
@@ -984,7 +984,7 @@ impl<'a> Str for CowString<'a> {
 }
 
 #[stable(feature = "rust1", since = "1.0.0")]
-impl fmt::Writer for String {
+impl fmt::Write for String {
     #[inline]
     fn write_str(&mut self, s: &str) -> fmt::Result {
         self.push_str(s);
diff --git a/src/libcollections/fmt.rs b/src/libcollections/fmt.rs
index 8f02f9fd580..a2273fe8755 100644
--- a/src/libcollections/fmt.rs
+++ b/src/libcollections/fmt.rs
@@ -179,7 +179,7 @@
 //!
 //! impl fmt::Display for Vector2D {
 //!     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
 //!         // The `f` value implements the `Writer` trait, which is what the
 //!         // write! macro is expecting. Note that this formatting ignores the
 //!         // various flags provided to format strings.
 //!         write!(f, "({}, {})", self.x, self.y)
@@ -403,7 +403,7 @@
 
 #![stable(feature = "rust1", since = "1.0.0")]
 
-pub use core::fmt::{Formatter, Result, Writer, rt};
+pub use core::fmt::{Formatter, Result, Write, rt};
 pub use core::fmt::{Show, String, Octal, Binary};
 pub use core::fmt::{Display, Debug};
 pub use core::fmt::{LowerHex, UpperHex, Pointer};
@@ -179,7 +179,7 @@
 //! impl fmt::Display for Vector2D {
 //!     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-//!         // The `f` value implements the `Writer` trait, which is what the
+//!         // The `f` value implements the `Write` trait, which is what the
 //!         // write! macro is expecting. Note that this formatting ignores the
 //!         // various flags provided to format strings.